==> icons-0.0.6.tgz: package/src/index.ts <==
import Add from "./Add.svg";
import AddPrivate from "./AddPrivate.svg";
import AddPrivate2 from "./AddPrivate2.svg";
import AddWindow from "./AddWindow.svg";
import All from "./All.svg";
import AppearanceFilled from "./AppearanceFilled.svg";
import Audio from "./Audio.svg";
import AudioNone from "./AudioNone.svg";
import Avatar from "./Avatar.svg";
import AvatarFilled from "./AvatarFilled.svg";
import Back from "./Back.svg";
import Biscuit from "./Biscuit.svg";
import Block from "./Block.svg";
import Bold from "./Bold.svg";
import BulletList from "./BulletList.svg";
import Cake from "./Cake.svg";
import Calculator from "./Calculator.svg";
import Calculator2 from "./Calculator2.svg";
import Calendar from "./Calendar.svg";
import Camera from "./Camera.svg";
import Certificate from "./Certificate.svg";
import Check from "./Check.svg";
import ChevonRight12 from "./ChevonRight12.svg";
import ChevronDown from "./ChevronDown.svg";
import ChevronDown12 from "./ChevronDown12.svg";
import ChevronLeft from "./ChevronLeft.svg";
import ChevronLeft12 from "./ChevronLeft12.svg";
import ChevronRight from "./ChevronRight.svg";
import ChevronUp from "./ChevronUp.svg";
import ChevronUp12 from "./ChevronUp12.svg";
import Clock from "./Clock.svg";
import Close from "./Close.svg";
import CloseTabs from "./CloseTabs.svg";
import CloseTabsToLeft from "./CloseTabsToLeft.svg";
import CloseTabsToRight from "./CloseTabsToRight.svg";
import Colour from "./Colour.svg";
import CompassFilled from "./CompassFilled.svg";
import Copy from "./Copy.svg";
import Cube from "./Cube.svg";
import Cut from "./Cut.svg";
import Desktop from "./Desktop.svg";
import Document from "./Document.svg";
import Download from "./Download.svg";
import Duplicate from "./Duplicate.svg";
import ExitFullscreen from "./ExitFullscreen.svg";
import ExtensionFilled from "./ExtensionFilled.svg";
import Eye from "./Eye.svg";
import Folder from "./Folder.svg";
import Forward from "./Forward.svg";
import Fullscreen from "./Fullscreen.svg";
import Gesture from "./Gesture.svg";
import Globe from "./Globe.svg";
import Grid from "./Grid.svg";
import GridAlt from "./GridAlt.svg";
import Help from "./Help.svg";
import Home from "./Home.svg";
import HomeFilled from "./HomeFilled.svg";
import Inbox from "./Inbox.svg";
import Info from "./Info.svg";
import InfoFilled from "./InfoFilled.svg";
import Inspect from "./Inspect.svg";
import Italic from "./Italic.svg";
import Javascript from "./Javascript.svg";
import KeyFilled from "./KeyFilled.svg";
import LabBottle from "./LabBottle.svg";
import Language from "./Language.svg";
import Loading from "./Loading.svg";
import LoadingBlack from "./LoadingBlack.svg";
import Location from "./Location.svg";
import Mail from "./Mail.svg";
import MailFilled from "./MailFilled.svg";
import Media from "./Media.svg";
import Menu from "./Menu.svg";
import Message from "./Message.svg";
import MoreHorizontal from "./MoreHorizontal.svg";
import MoreVertical from "./MoreVertical.svg";
import NewBookmark from "./NewBookmark.svg";
import NewFolder from "./NewFolder.svg";
import NewNote from "./NewNote.svg";
import News from "./News.svg";
import Night from "./Night.svg";
import Notepad from "./Notepad.svg";
import NumberList from "./NumberList.svg";
import OpenFolder from "./OpenFolder.svg";
import OpenInNew from "./OpenInNew.svg";
import Paste from "./Paste.svg";
import Pause from "./Pause.svg";
import Pdf from "./Pdf.svg";
import Permission from "./Permission.svg";
import Phone from "./Phone.svg";
import Photo from "./Photo.svg";
import Pip from "./Pip.svg";
import Play from "./Play.svg";
import PlayFilled from "./PlayFilled.svg";
import Print from "./Print.svg";
import PrintFilled from "./PrintFilled.svg";
import Processes from "./Processes.svg";
import Qrcode from "./Qrcode.svg";
import Redo from "./Redo.svg";
import Refresh from "./Refresh.svg";
import Rss from "./Rss.svg";
import Save from "./Save.svg";
import Screenshot from "./Screenshot.svg";
import Search from "./Search.svg";
import SearchSidebar from "./SearchSidebar.svg";
import Secure from "./Secure.svg";
import SecureFilled from "./SecureFilled.svg";
import Settings from "./Settings.svg";
import SettingsFilled from "./SettingsFilled.svg";
import ShoppingBag from "./ShoppingBag.svg";
import SidebarsLeft from "./SidebarsLeft.svg";
import SidebarsRight from "./SidebarsRight.svg";
import Star from "./Star.svg";
import StarFilled from "./StarFilled.svg";
import StarFilled12 from "./StarFilled12.svg";
import StarInTray from "./StarInTray.svg";
import Stocks from "./Stocks.svg";
import Stop from "./Stop.svg";
import Stopwatch from "./Stopwatch.svg";
import Strikethrough from "./Strikethrough.svg";
import Subtitles from "./Subtitles.svg";
import Sun from "./Sun.svg";
import Swap from "./Swap.svg";
import Sync from "./Sync.svg";
import Tablet from "./Tablet.svg";
import Tag from "./Tag.svg";
import TagAlt from "./TagAlt.svg";
import Title1 from "./Title1.svg";
import Title2 from "./Title2.svg";
import Title3 from "./Title3.svg";
import Trash from "./Trash.svg";
import Tv from "./Tv.svg";
import Underline from "./Underline.svg";
import Undo from "./Undo.svg";
import UnsecureFilled from "./UnsecureFilled.svg";
import UnsecureWarningFilled from "./UnsecureWarningFilled.svg";
import UpdateFilled from "./UpdateFilled.svg";
import Upload from "./Upload.svg";
import Usb from "./Usb.svg";
import User from "./User.svg";
import UserFilled from "./UserFilled.svg";
import Video from "./Video.svg";
import VideoCamera from "./VideoCamera.svg";
import WarningFilled from "./WarningFilled.svg";
import Weather from "./Weather.svg";
import WeatherFilled from "./WeatherFilled.svg";
import WeatherFilledQuestion from "./WeatherFilledQuestion.svg";
import ZoomIn from "./ZoomIn.svg";
import ZoomOut from "./ZoomOut.svg";

export default {
	Home,
	Back,
	Forward,
	Refresh,
	Secure,
	Search,
	Star,
	Add,
	Close,
	Avatar,
	Document,
	Info,
	Print,
	Check,
	Inspect,
	Save,
	Download,
	Sync,
	Language,
	OpenInNew,
	Gesture,
	Grid,
	Globe,
	ShoppingBag,
	ChevronLeft,
	ChevronRight,
	ChevronDown,
	ChevronUp,
	Menu,
	StarInTray,
	Desktop,
	Tablet,
	Phone,
	Tv,
	Copy,
	Cut,
	Paste,
	Folder,
	Qrcode,
	GridAlt,
	Certificate,
	Biscuit,
	Permission,
	Location,
	NewFolder,
	OpenFolder,
	Trash,
	Notepad,
	NewNote,
	Bold,
	Italic,
	Underline,
	Strikethrough,
	BulletList,
	NumberList,
	Title1,
	Title2,
	Title3,
	Calculator,
	Tag,
	Clock,
	NewBookmark,
	All,
	Pdf,
	Javascript,
	Sun,
	Night,
	User,
	Mail,
	Colour,
	MoreHorizontal,
	TagAlt,
	Processes,
	Rss,
	Media,
	Stocks,
	Weather,
	Cube,
	News,
	SearchSidebar,
	SidebarsLeft,
	SidebarsRight,
	Play,
	Pause,
	Subtitles,
	Audio,
	AudioNone,
	Fullscreen,
	ExitFullscreen,
	Pip,
	Calculator2,
	Duplicate,
	CloseTabsToRight,
	CloseTabs,
	CloseTabsToLeft,
	Photo,
	Video,
	AddWindow,
	AddPrivate,
	AddPrivate2,
	Help,
	Screenshot,
	Undo,
	Redo,
	Block,
	Eye,
	Message,
	Loading,
	LoadingBlack,
	ZoomIn,
	ZoomOut,
	Usb,
	Swap,
	Stop,
	Stopwatch,
	Settings,
	Inbox,
	VideoCamera,
	Calendar,
	Cake,
	Camera,
	Upload,
	LabBottle,
	MoreVertical,
	MailFilled,
	PlayFilled,
	WeatherFilled,
	WeatherFilledQuestion,
	StarFilled,
	PrintFilled,
	AppearanceFilled,
	AvatarFilled,
	CompassFilled,
	HomeFilled,
	SecureFilled,
	UnsecureFilled,
	UnsecureWarningFilled,
	WarningFilled,
	InfoFilled,
	KeyFilled,
	UpdateFilled,
	ExtensionFilled,
	SettingsFilled,
	UserFilled,
	StarFilled12,
	ChevronLeft12,
	ChevronUp12,
	ChevonRight12,
	ChevronDown12,
};

==> icons-0.0.7.tgz: package/src/index.ts <==
import Accessibility from "./Accessibility.svg";
import Add from "./Add.svg";
import AddPrivate from "./AddPrivate.svg";
import AddPrivate2 from "./AddPrivate2.svg";
import AddWindow from "./AddWindow.svg";
import All from "./All.svg";
import Anchor from "./Anchor.svg";
import AppearanceFilled from "./AppearanceFilled.svg";
import Audio from "./Audio.svg";
import AudioNone from "./AudioNone.svg";
import Avatar from "./Avatar.svg";
import AvatarFilled from "./AvatarFilled.svg";
import Back from "./Back.svg";
import Bell from "./Bell.svg";
import Biscuit from "./Biscuit.svg";
import Block from "./Block.svg";
import BlockFilled from "./BlockFilled.svg";
import Bold from "./Bold.svg";
import Building from "./Building.svg";
import BulletList from "./BulletList.svg";
import Cake from "./Cake.svg";
import CakeFilled from "./CakeFilled.svg";
import Calculator from "./Calculator.svg";
import Calculator2 from "./Calculator2.svg";
import Calendar from "./Calendar.svg";
import CalendarMonths from "./CalendarMonths.svg";
import Camera from "./Camera.svg";
import CameraFilled from "./CameraFilled.svg";
import Car from "./Car.svg";
import Certificate from "./Certificate.svg";
import Check from "./Check.svg";
import ChevonRight12 from "./ChevonRight12.svg";
import ChevronDown from "./ChevronDown.svg";
import ChevronDown12 from "./ChevronDown12.svg";
import ChevronLeft from "./ChevronLeft.svg";
import ChevronLeft12 from "./ChevronLeft12.svg";
import ChevronRight from "./ChevronRight.svg";
import ChevronUp from "./ChevronUp.svg";
import ChevronUp12 from "./ChevronUp12.svg";
import Clock from "./Clock.svg";
import ClockFilled from "./ClockFilled.svg";
import Close from "./Close.svg";
import CloseTabs from "./CloseTabs.svg";
import CloseTabsToLeft from "./CloseTabsToLeft.svg";
import CloseTabsToRight from "./CloseTabsToRight.svg";
import Colour from "./Colour.svg";
import CompassFilled from "./CompassFilled.svg";
import Copy from "./Copy.svg";
import Cube from "./Cube.svg";
import CubeFilled from "./CubeFilled.svg";
import Cut from "./Cut.svg";
import Desktop from "./Desktop.svg";
import Document from "./Document.svg";
import Download from "./Download.svg";
import DuplicateWindow from "./DuplicateWindow.svg";
import ExitFullscreen from "./ExitFullscreen.svg";
import ExtensionFilled from "./ExtensionFilled.svg";
import Eye from "./Eye.svg";
import EyeFilled from "./EyeFilled.svg";
import Folder from "./Folder.svg";
import Forward from "./Forward.svg";
import Fullscreen from "./Fullscreen.svg";
import Gesture from "./Gesture.svg";
import Globe from "./Globe.svg";
import Gps from "./Gps.svg";
import Grid from "./Grid.svg";
import GridAlt from "./GridAlt.svg";
import Help from "./Help.svg";
import HelpFilled from "./HelpFilled.svg";
import Home from "./Home.svg";
import HomeFilled from "./HomeFilled.svg";
import Inbox from "./Inbox.svg";
import Info from "./Info.svg";
import InfoFilled from "./InfoFilled.svg";
import Inspect from "./Inspect.svg";
import Italic from "./Italic.svg";
import Javascript from "./Javascript.svg";
import KeyFilled from "./KeyFilled.svg";
import LabBottle from "./LabBottle.svg";
import Language from "./Language.svg";
import Lightbulb from "./Lightbulb.svg";
import Loading from "./Loading.svg";
import LoadingBlack from "./LoadingBlack.svg";
import Location from "./Location.svg";
import LocationFilled from "./LocationFilled.svg";
import Mail from "./Mail.svg";
import MailFilled from "./MailFilled.svg";
import Media from "./Media.svg";
import Menu from "./Menu.svg";
import Message from "./Message.svg";
import Microphone from "./Microphone.svg";
import MoreHorizontal from "./MoreHorizontal.svg";
import Network from "./Network.svg";
import NewBookmark from "./NewBookmark.svg";
import NewNote from "./NewNote.svg";
import News from "./News.svg";
import NewsFilled from "./NewsFilled.svg";
import Night from "./Night.svg";
import Notepad from "./Notepad.svg";
import OpenInNew from "./OpenInNew.svg";
import PaintBrush from "./PaintBrush.svg";
import Paste from "./Paste.svg";
import Pause from "./Pause.svg";
import Pdf from "./Pdf.svg";
import Permission from "./Permission.svg";
import Phone from "./Phone.svg";
import PhoneHorizontal from "./PhoneHorizontal.svg";
import Photo from "./Photo.svg";
import PhotoFilled from "./PhotoFilled.svg";
import Pip from "./Pip.svg";
import Play from "./Play.svg";
import PlayFilled from "./PlayFilled.svg";
import Print from "./Print.svg";
import PrintFilled from "./PrintFilled.svg";
import Processes from "./Processes.svg";
import ProcessesFilled from "./ProcessesFilled.svg";
import Qrcode from "./Qrcode.svg";
import Redo from "./Redo.svg";
import Refresh from "./Refresh.svg";
import Robot from "./Robot.svg";
import Rss from "./Rss.svg";
import RssFilled from "./RssFilled.svg";
import Save from "./Save.svg";
import Screenshot from "./Screenshot.svg";
import Search from "./Search.svg";
import SearchSidebar from "./SearchSidebar.svg";
import Secure from "./Secure.svg";
import SecureFilled from "./SecureFilled.svg";
import Send from "./Send.svg";
import SendFilled from "./SendFilled.svg";
import Settings from "./Settings.svg";
import SettingsFilled from "./SettingsFilled.svg";
import Share from "./Share.svg";
import ShoppingBag from "./ShoppingBag.svg";
import SidebarsLeft from "./SidebarsLeft.svg";
import SidebarsLeftFilled from "./SidebarsLeftFilled.svg";
import SidebarsRight from "./SidebarsRight.svg";
import SidebarsRightFilled from "./SidebarsRightFilled.svg";
import Star from "./Star.svg";
import StarFilled from "./StarFilled.svg";
import StarFilled12 from "./StarFilled12.svg";
import StarInTray from "./StarInTray.svg";
import Stocks from "./Stocks.svg";
import StocksFilld from "./StocksFilld.svg";
import Stop from "./Stop.svg";
import Stopwatch from "./Stopwatch.svg";
import Strikethrough from "./Strikethrough.svg";
import Subtitles from "./Subtitles.svg";
import SubtitlesFilled from "./SubtitlesFilled.svg";
import Sun from "./Sun.svg";
import Swap from "./Swap.svg";
import Sync from "./Sync.svg";
import Tag from "./Tag.svg";
import TagAlt from "./TagAlt.svg";
import TagAltFilled from "./TagAltFilled.svg";
import TagFilled from "./TagFilled.svg";
import Terminal from "./Terminal.svg";
import Train from "./Train.svg";
import Trash from "./Trash.svg";
import Tv from "./Tv.svg";
import Underline from "./Underline.svg";
import Undo from "./Undo.svg";
import UnsecureFilled from "./UnsecureFilled.svg";
import UnsecureWarningFilled from "./UnsecureWarningFilled.svg";
import UpdateFilled from "./UpdateFilled.svg";
import Upload from "./Upload.svg";
import Usb from "./Usb.svg";
import User from "./User.svg";
import UserFilled from "./UserFilled.svg";
import Video from "./Video.svg";
import VideoCamera from "./VideoCamera.svg";
import VideoCameraFilled from "./VideoCameraFilled.svg";
import VideoFilled from "./VideoFilled.svg";
import WarningFilled from "./WarningFilled.svg";
import Waveform from "./Waveform.svg";
import Weather from "./Weather.svg";
import WeatherFilled from "./WeatherFilled.svg";
import WeatherFilledQuestion from "./WeatherFilledQuestion.svg";
import WifiDisconnected from "./WifiDisconnected.svg";
import WifiFull from "./WifiFull.svg";
import WifiIssues1 from "./WifiIssues1.svg";
import WifiIssues2 from "./WifiIssues2.svg";
import WifiIssues3 from "./WifiIssues3.svg";
import ZoomIn from "./ZoomIn.svg";
import ZoomOut from "./ZoomOut.svg";

export default {
	Home,
	Back,
	Forward,
	Refresh,
	Secure,
	Search,
	Star,
	Add,
	Close,
	Avatar,
	Document,
	Print,
	Check,
	Inspect,
	Save,
	Download,
	Sync,
	Language,
	OpenInNew,
	Gesture,
	Grid,
	Globe,
	Mail,
	ShoppingBag,
	ChevronLeft,
	ChevronRight,
	ChevronDown,
	ChevronUp,
	Menu,
	StarInTray,
	Desktop,
	PhoneHorizontal,
	Phone,
	Tv,
	Copy,
	Cut,
	Paste,
	DuplicateWindow,
	Folder,
	Qrcode,
	GridAlt,
	Certificate,
	Biscuit,
	Permission,
	Location,
	Usb,
	Trash,
	Notepad,
	NewNote,
	Bold,
	Italic,
	Underline,
	Strikethrough,
	BulletList,
	Calculator,
	Tag,
	Clock,
	NewBookmark,
	All,
	Pdf,
	Javascript,
	Sun,
	Night,
	User,
	Swap,
	Calculator2,
	Colour,
	MoreHorizontal,
	Stopwatch,
	TagAlt,
	Processes,
	Rss,
	Media,
	Stocks,
	Weather,
	Cube,
	News,
	SearchSidebar,
	SidebarsLeft,
	SidebarsRight,
	Play,
	Pause,
	Stop,
	Subtitles,
	Audio,
	AudioNone,
	Fullscreen,
	ExitFullscreen,
	Pip,
	CloseTabsToRight,
	CloseTabs,
	CloseTabsToLeft,
	Photo,
	Video,
	AddWindow,
	AddPrivate,
	AddPrivate2,
	Help,
	Info,
	Screenshot,
	Undo,
	Redo,
	Block,
	Eye,
	Message,
	Loading,
	LoadingBlack,
	ZoomIn,
	ZoomOut,
	Settings,
	Inbox,
	VideoCamera,
	Cake,
	Camera,
	Upload,
	LabBottle,
	Send,
	Building,
	Calendar,
	CalendarMonths,
	Gps,
	Robot,
	Waveform,
	Lightbulb,
	Terminal,
	Share,
	Microphone,
	WifiFull,
	WifiIssues1,
	WifiIssues2,
	WifiIssues3,
	WifiDisconnected,
	Anchor,
	Car,
	Train,
	Accessibility,
	PaintBrush,
	Bell,
	Network,
	MailFilled,
	PlayFilled,
	WeatherFilled,
	WeatherFilledQuestion,
	StarFilled,
	PrintFilled,
	AppearanceFilled,
	AvatarFilled,
	CompassFilled,
	HomeFilled,
	SecureFilled,
	UnsecureFilled,
	UnsecureWarningFilled,
	WarningFilled,
	InfoFilled,
	HelpFilled,
	KeyFilled,
	UpdateFilled,
	ExtensionFilled,
	SettingsFilled,
	UserFilled,
	SendFilled,
	LocationFilled,
	PhotoFilled,
	VideoFilled,
	SubtitlesFilled,
	TagFilled,
	TagAltFilled,
	ClockFilled,
	BlockFilled,
	ProcessesFilled,
	RssFilled,
	StocksFilld,
	CubeFilled,
	NewsFilled,
	SidebarsLeftFilled,
	SidebarsRightFilled,
	EyeFilled,
	VideoCameraFilled,
	CakeFilled,
	CameraFilled,
	StarFilled12,
	ChevronLeft12,
	ChevronUp12,
	ChevonRight12,
	ChevronDown12,
};
